summaryrefslogtreecommitdiffstats
path: root/module/plugins/Hoster.py
diff options
context:
space:
mode:
authorGravatar RaNaN <Mast3rRaNaN@hotmail.de> 2012-03-06 13:36:39 +0100
committerGravatar RaNaN <Mast3rRaNaN@hotmail.de> 2012-03-06 13:36:39 +0100
commit4df2b77fdf42046fe19bd371be7c7255986b5980 (patch)
tree2a7227a0d22e03dc2c085514eaab36a7e5e612c4 /module/plugins/Hoster.py
parentssl fix (diff)
downloadpyload-4df2b77fdf42046fe19bd371be7c7255986b5980.tar.xz
renamed hooks to addons, new filemanager and database, many new api methods
you will loose ALL your LINKS, webinterface will NOT work
Diffstat (limited to 'module/plugins/Hoster.py')
-rw-r--r--module/plugins/Hoster.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/module/plugins/Hoster.py b/module/plugins/Hoster.py
index fc9e23132..32c587aa5 100644
--- a/module/plugins/Hoster.py
+++ b/module/plugins/Hoster.py
@@ -185,7 +185,7 @@ class Hoster(Base):
10 - not implemented
20 - unknown error
"""
#@TODO checksum check hook
return True, 10
@@ -365,7 +365,7 @@ class Hoster(Base):
filename = join(location, name)
- self.core.hookManager.dispatchEvent("downloadStarts", self.pyfile, url, filename)
+ self.core.addonManager.dispatchEvent("downloadStarts", self.pyfile, url, filename)
try:
newname = self.req.httpDownload(url, filename, get=get, post=post, ref=ref, cookies=cookies,
@@ -185,7 +185,7 @@ class Hoster(Base):
20 - unknown error
"""
- #@TODO checksum check hook
+ #@TODO checksum check addon
return True, 10